Index: packages/adlo/adlo.mk
===================================================================
--- packages/adlo/adlo.mk	(revision 0)
+++ packages/adlo/adlo.mk	(revision 0)
@@ -0,0 +1,63 @@
+ADLO_URL=svn://coreboot.org/repos/trunk/payloads/adlo
+ADLO_TAG=3276
+
+ADLO_DIR=$(BUILD_DIR)/svn
+ADLO_SRC_DIR=$(ADLO_DIR)/svn
+ADLO_STAMP_DIR=$(ADLO_DIR)/stamps
+ADLO_LOG_DIR=$(ADLO_DIR)/logs
+
+
+ifeq ($(CONFIG_VERBOSE),y)
+ADLO_FETCH_LOG=/dev/stdout
+ADLO_BUILD_LOG=/dev/stdout
+else
+ADLO_BUILD_LOG=$(ADLO_LOG_DIR)/build.log
+ADLO_FETCH_LOG=$(ADLO_LOG_DIR)/fetch.log
+endif
+
+# Make sure we have the tools we need to accomplish this
+HAVE_AS86:=$(call find-tool,as86)
+
+ifeq ($(HAVE_AS86),n)
+$(error To build ADLO, you need to install as86, available in dev86)
+endif
+
+ADLO_TARBALL=adlo-svn-$(ADLO_TAG).tar.gz
+
+$(SOURCE_DIR)/$(ADLO_TARBALL): | $(ADLO_LOG_DIR)
+	@ mkdir -p $(SOURCE_DIR)/adlo
+	@ $(BIN_DIR)/fetchsvn.sh $(ADLO_URL) $(SOURCE_DIR)/adlo \
+	$(ADLO_TAG) $(SOURCE_DIR)/$(ADLO_TARBALL) \
+	> $(ADLO_FETCH_LOG) 2>&1
+
+$(ADLO_STAMP_DIR)/.unpacked: $(SOURCE_DIR)/$(ADLO_TARBALL) | $(ADLO_STAMP_DIR) $(ADLO_LOG_DIR) $(ADLO_DIR)
+	@ echo "Unpacking ADLO..."
+	@ tar -C $(ADLO_DIR) -zxf $(SOURCE_DIR)/$(ADLO_TARBALL)
+	@ ln -s $(LEGACYBIOS_SRC_DIR)/out/ $(ADLO_DIR)/svn/legacybios
+	@ touch $@
+
+
+$(ADLO_SRC_DIR)/adlo.elf: $(ADLO_STAMP_DIR)/.unpacked $(LEGACYBIOS_SRC_DIR)/out/rom.bin
+	@ echo "Building ADLO..."
+	@ make -C $(ADLO_SRC_DIR) > $(ADLO_BUILD_LOG) 2>&1
+
+$(ADLO_STAMP_DIR)/.copied: $(ADLO_SRC_DIR)/adlo.elf
+	@ mkdir -p $(shell dirname $(PAYLOAD_ELF))
+	@ cp $(ADLO_SRC_DIR)/adlo.elf $(PAYLOAD_ELF)
+	@ touch $@
+
+$(ADLO_STAMP_DIR) $(ADLO_LOG_DIR):
+	@ mkdir -p $@
+
+adlo: $(ADLO_STAMP_DIR)/.copied
+
+adlo-clean:
+	@ echo "Cleaning ADLO..."
+	@ rm -f $(ADLO_STAMP_DIR)/.copied
+ifneq ($(wildcard $(ADLO_SRC_DIR)/Makefile),)
+	@ $(MAKE) -C $(ADLO_SRC_DIR) clean > /dev/null 2>&1
+endif
+
+adlo-distclean:
+	@ rm -rf $(ADLO_DIR)/*
+
Index: packages/legacybios/legacybios.mk
===================================================================
--- packages/legacybios/legacybios.mk	(revision 0)
+++ packages/legacybios/legacybios.mk	(revision 0)
@@ -0,0 +1,53 @@
+LEGACYBIOS_URL=http://linuxtogo.org/~kevin/legacybios/
+LEGACYBIOS_TAG=0.2.0
+
+LEGACYBIOS_DIR=$(BUILD_DIR)/legacybios
+LEGACYBIOS_SRC_DIR=$(LEGACYBIOS_DIR)/legacybios-$(LEGACYBIOS_TAG)
+LEGACYBIOS_STAMP_DIR=$(LEGACYBIOS_DIR)/stamps
+LEGACYBIOS_LOG_DIR=$(LEGACYBIOS_DIR)/logs
+
+LEGACYBIOS_PATCHES=
+
+ifeq ($(CONFIG_VERBOSE),y)
+LEGACYBIOS_FETCH_LOG=/dev/stdout
+LEGACYBIOS_BUILD_LOG=/dev/stdout
+else
+LEGACYBIOS_BUILD_LOG=$(LEGACYBIOS_LOG_DIR)/build.log
+LEGACYBIOS_FETCH_LOG=$(LEGACYBIOS_LOG_DIR)/fetch.log
+endif
+
+LEGACYBIOS_TARBALL=legacybios-$(LEGACYBIOS_TAG).tar.gz
+
+ifeq ($(shell if [ -f $(PACKAGE_DIR)/legacybios/conf/customconfig--$(PAYLOAD)--$(COREBOOT_VENDOR)-$(COREBOOT_BOARD) ]; then echo 1; fi),1)
+	LEGACYBIOS_CONFIG = customconfig--$(PAYLOAD)--$(COREBOOT_VENDOR)-$(COREBOOT_BOARD)
+endif
+
+$(SOURCE_DIR)/$(LEGACYBIOS_TARBALL): 
+	@ mkdir -p $(SOURCE_DIR)
+	@ wget $(WGET_Q) -P $(SOURCE_DIR) $(LEGACYBIOS_URL)/$(LEGACYBIOS_TARBALL) -O $(SOURCE_DIR)/$(LEGACYBIOS_TARBALL)
+
+$(LEGACYBIOS_STAMP_DIR)/.unpacked: $(SOURCE_DIR)/$(LEGACYBIOS_TARBALL) | $(LEGACYBIOS_STAMP_DIR) $(LEGACYBIOS_DIR) $(LEGACYBIOS_LOG_DIR)
+	@ echo "Unpacking legacybios..."
+	@ tar -C $(LEGACYBIOS_DIR) -zxf $(SOURCE_DIR)/$(LEGACYBIOS_TARBALL)
+	@ touch $@      
+
+$(LEGACYBIOS_SRC_DIR)/out/rom.bin: $(LEGACYBIOS_STAMP_DIR)/.unpacked
+	@ echo "Building legacybios..."
+	@ echo $(LEGACYBIOS_SRC_DIR)
+	@ make -C $(LEGACYBIOS_SRC_DIR) > $(LEGACYBIOS_BUILD_LOG) 2>&1
+
+$(LEGACYBIOS_STAMP_DIR) $(LEGACYBIOS_LOG_DIR):
+	@ mkdir -p $@
+
+legacybios: $(LEGACYBIOS_SRC_DIR)/out/rom.bin
+
+legacybios-clean:
+	@ echo "Cleaning legacybios..."
+	@ rm -f $(LEGACYBIOS_STAMP_DIR)/.copied
+ifneq ($(wildcard $(LEGACYBIOS_SRC_DIR)/Makefile),)
+	@ $(MAKE) -C $(LEGACYBIOS_SRC_DIR) clean > /dev/null 2>&1
+endif
+
+legacybios-distclean:
+	@ rm -rf $(LEGACYBIOS_DIR)/*
+
Index: config/payloads/payloads.conf
===================================================================
--- config/payloads/payloads.conf	(revision 174)
+++ config/payloads/payloads.conf	(working copy)
@@ -16,6 +16,7 @@
 ### Include the correct payload configuration
 
 PCONF-y=
+PCONF-$(CONFIG_PAYLOAD_ADLO) = adlo.conf
 PCONF-$(CONFIG_PAYLOAD_LAB) = lab.conf
 PCONF-$(CONFIG_PAYLOAD_ETHERBOOT) = etherboot.conf
 PCONF-$(CONFIG_PAYLOAD_GPXE) = gpxe.conf
@@ -29,6 +30,10 @@
 PCONF-$(CONFIG_PAYLOAD_TINT) = tint.conf
 PCONF-$(CONFIG_PAYLOAD_GRUB2) = grub2.conf
 
+ifeq ($(PCONF-y),)
+$(error No payload .conf file specified.)
+endif
+
 DEPENDS-y=
 include $(CONFIG_DIR)/payloads/$(PCONF-y)
 
Index: config/payloads/adlo.conf
===================================================================
--- config/payloads/adlo.conf	(revision 0)
+++ config/payloads/adlo.conf	(revision 0)
@@ -0,0 +1,15 @@
+# Configuration file for the ADLO payload
+
+# Common configuration options
+
+PAYLOAD_BUILD=scripts/Makefile.generic
+
+PAYLOAD_ELF=$(OUTPUT_DIR)/adlo-payload.elf
+PAYLOAD_COMPRESSED=$(OUTPUT_DIR)/adlo-payload.elf.lzma
+
+PAYLOAD=adlo
+PAYLOAD-y=adlo
+
+# Add legacybios as a dependency
+PAYLOAD_AND_DEP_MK=$(PACKAGE_DIR)/legacybios/legacybios.mk $(PACKAGE_DIR)/adlo/adlo.mk
+DEPENDS-y +=legacybios
Index: config/payloads/Config.in
===================================================================
--- config/payloads/Config.in	(revision 174)
+++ config/payloads/Config.in	(working copy)
@@ -9,6 +9,9 @@
 	help
 	  Buildrom can build a number of different payloads for the ROM
 
+config PAYLOAD_ADLO
+	bool "ADLO (Bochs BIOS with a wrapper for Coreboot)"
+
 config PAYLOAD_COREINFO
 	bool "Coreinfo"
 
